@@ -29,9 +29,9 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 /* prototype definitions */
 int emptyline(char *);
 int iscomment(char *);
-int isnumber(char *);
 int isserver(char *);
 int isvaliduserhost(char *);
+int isvalidhost(char *);
 int isansi(char *);
 int isaction(char *);
 int isctcp(char *);
@@ -39,8 +39,11 @@ int wordcount(char *);
 int parse(char *, int, char *, char *, int, int);
 int issamenickandhost(char *, char *, char *, char *);
 int issimilarstring(char *, char *);
+int isnumbw(int, int, int);
+int completeban(char *, char *, int);
 unsigned int longestword(char *);
 unsigned int isgoodquote(char *);
+char *mybasename(char *);
 void striplf(char *);
 void stripchars(char *, char *);
 void stripcntrl(char *);
@@ -98,6 +101,7 @@ void oer_debug(int level, const char *fmt, ...)
                 if(do_output) {
                         vfprintf(mystate->logto, fmt, ap);
 			if(mystate->outputcounter >= OER_FORCE_FLUSH) {
+				/* we cant output a possible failure */
 				fflush(mystate->logto);
 				mystate->outputcounter = 0;
 			}
@@ -320,19 +324,6 @@ void striplf(char *line)
 	}
 }
 
-int isnumber(char *line)
-{
-	int length;
-	int i;
-
-	for(i = 0, length = strlen(line); line[i] != '\0' && i < length; i++) {
-		if(!isdigit((int)line[i])) {
-			return 0;
-		}
-	}
-	return 1;
-}
-
 int isserver(char *line)
 {
 	int i;
@@ -600,3 +591,89 @@ int issimilarstring(char *s1, char *s2)
         }
         return 0;
 }
+
+int isnumbw(int number, int low, int high)
+{
+	if(number >= low && number <= high) {
+		return 1;
+	} else {
+#ifdef DEBUG
+		oer_debug(OER_DEBUG_INFO, "isnumbw->%d is not >= %d and <= %d\n", number, low, high);
+#endif
+		return 0;
+	}
+}
+
+int isvalidhost(char *line)
+{
+        int c;
+        int c2;
+        char *ptr;
+
+        /* we require at least X.Y */
+        if(strlen(line) < 3) {
+                return 0;
+        }
+        /* we require a domain and a TLD */
+        if((ptr = index(line, '.')) == NULL) {
+                return 0;
+        }
+        /* the domain and TLD separator can't be the
+           first nor the last character */
+        if(ptr == line || ptr == (line + (strlen(line) - 1))) {
+                return 0;
+        }
+        c = *(ptr - 1);
+        c2 = *(ptr + 1);
+        /* we want both X and Y to be printable */
+        if(!isgraph(c) || !isgraph(c2)) {
+                return 0;
+        }
+        return 1;
+}
+
+int completeban(char *from, char *to, int tlength)
+{
+	int rc;
+	char *ptr1;
+	char *ptr2;
+	char *ptr3;
+
+	ptr1 = index(from, (int)'!');
+	ptr2 = index(from, (int)'@');
+	ptr3 = index(from, (int)'.');
+	if(ptr1 == NULL && ptr2 == NULL) {
+		/* nick ban */
+		rc = snprintf(to, tlength, "%s!*@*", from);
+	} else if(ptr1 == NULL && ptr2 != NULL) {
+		/* ident@host */
+		rc = snprintf(to, tlength, "*!%s", from);
+	} else if(ptr1 == NULL && ptr2 == NULL && ptr3 != NULL) {
+		/* host.xxx */
+		rc = snprintf(to, tlength, "*!*@%s", from);
+	} else if(ptr1 != NULL && ptr2 == NULL){
+		/* nick!ident */
+		rc = snprintf(to, tlength, "%s@*", from);
+	} else {
+		/* dont know */
+		rc = snprintf(to, tlength, "%s", from);
+	}
+	return rc;
+}
+
+char *mybasename(char *ptr)
+{
+	int length;
+	int counter;
+
+	length = strlen(ptr);
+	counter = length - 1;
+	while(counter >= 0 && ptr[counter] != '/') {
+		counter--;
+	}
+	if(counter >= 0) {
+		return ptr + counter + 1;
+	} else {
+		return NULL;
+	}
+}
