@@ -170,6 +170,8 @@ enum WHICHCOMMAND_RETURN_VALUES {
 	OER_WHICHCOMMAND_BSTATS,
 	OER_WHICHCOMMAND_EXT,
 	OER_WHICHCOMMAND_RESET,
+	OER_WHICHCOMMAND_CHANINFO,
+	OER_WHICHCOMMAND_QUEUESTATS,
 	OER_WHICHCOMMAND_INVALID
 };
 
@@ -270,6 +272,52 @@ enum OER_FLAGS_TYPE {
 /* from glib.h */
 #define ABS(a)         (((a) < 0) ? -(a) : (a))
 
+#define OER_LIMIT_SERVER_PORT_MIN 1
+#define OER_LIMIT_SERVER_PORT_MAX 65536
+#define OER_LIMIT_SERVER_MODES_MIN 1
+#define OER_LIMIT_SERVER_MODES_MAX 6
+#define OER_LIMIT_SERVER_PING_MIN 10
+#define OER_LIMIT_SERVER_PING_MAX 86400
+#define OER_LIMIT_SERVER_PROTOPER_MIN 0
+#define OER_LIMIT_SERVER_PROTOPER_MAX 1
+#define OER_LIMIT_BANVARS_AUTOREJOIN_MIN 0
+#define OER_LIMIT_BANVARS_AUTOREJOIN_MAX 86400
+#define OER_LIMIT_BANVARS_PARTREJOIN_MIN 0
+#define OER_LIMIT_BANVARS_PARTREJOIN_MAX 86400
+#define OER_LIMIT_BANVARS_PUBLICFLOOD_MIN 0
+#define OER_LIMIT_BANVARS_PUBLICFLOOD_MAX 86400
+#define OER_LIMIT_BANVARS_PUBLICFLOODREPEAT_MIN 0
+#define OER_LIMIT_BANVARS_PUBLICFLOODREPEAT_MAX 86400
+#define OER_LIMIT_BANVARS_BADWORD_MIN 0
+#define OER_LIMIT_BANVARS_BADWORD_MAX 86400
+#define OER_LIMIT_BANVARS_BADNICK_MIN 0
+#define OER_LIMIT_BANVARS_BADNICK_MAX 86400
+#define OER_LIMIT_BANVARS_NORMALBAN_MIN 0
+#define OER_LIMIT_BANVARS_NORMALBAN_MAX 86400
+#define OER_LIMIT_CHANNEL_CHANLIMIT_MIN 1
+#define OER_LIMIT_CHANNEL_CHANLIMIT_MAX 99999
+#define OER_LIMIT_FLOODVARS_REPEAT_EXPIRE_MIN 1
+#define OER_LIMIT_FLOODVARS_REPEAT_EXPIRE_MAX 86400
+#define OER_LIMIT_FLOODVARS_REPEAT_LIMIT_MIN 1
+#define OER_LIMIT_FLOODVARS_REPEAT_LIMIT_MAX 1000
+#define OER_LIMIT_FLOODVARS_INTERVAL_MIN 1
+#define OER_LIMIT_FLOODVARS_INTERVAL_MAX 86400
+#define OER_LIMIT_FLOODVARS_LINES_MIN 1
+#define OER_LIMIT_FLOODVARS_LINES_MAX 1000
+#define OER_LIMIT_FLOODVARS_CHARS_MIN 1
+#define OER_LIMIT_FLOODVARS_CHARS_MAX 100000
+#define OER_LIMIT_FLOODVARS_NICKFLOOD_EXPIRE_MIN 1
+#define OER_LIMIT_FLOODVARS_NICKFLOOD_EXPIRE_MAX 86400
+#define OER_LIMIT_FLOODVARS_NICKFLOOD_LIMIT_MIN 1
+#define OER_LIMIT_FLOODVARS_NICKFLOOD_LIMIT_MAX 1000
+#define OER_LIMIT_LISTCOMMAND_STARTPOS_MIN 1
+#define OER_LIMIT_LISTCOMMAND_STARTPOS_MAX 1000
+#define OER_LIMIT_TOPICS_MIN 1
+#define OER_LIMIT_TOPICS_MAX OER_TOPICS
+#define OER_LIMIT_SHOWLAST_MIN 1
+#define OER_LIMIT_SHOWLAST_MAX OER_LAST_MAX
+#define OER_LIMIT_SHOWSEEN_MIN 1
+#define OER_LIMIT_SHOWSEEN_MAX OER_SEEN_MAX
 #define OER_MAINLOOP_TIMEOUT_SECS 1
 #define OER_MAINLOOP_TIMEOUT_USECS 0
 /* only change this if you are 100% sure what you are doing */
@@ -296,6 +344,8 @@ enum OER_FLAGS_TYPE {
 #define OER_DELAY_BETWEEN_REJOINS_CYCLE 1
 #define OER_AUTO_REJOIN_TIME 3
 #define OER_QUOTE_INTERVAL 300
+#define OER_ADVERT_INTERVAL 300
+#define OER_Q_QUERY_INTERVAL 10
 #define OER_ALLOWED_PARTS OER_PARTS / 5
 #define OER_RECONNECT_DELAY 30
 #define OER_NETJOIN_DELAY 15
@@ -303,7 +353,7 @@ enum OER_FLAGS_TYPE {
 #define OER_NICKCHANGES 20
 #define OER_TOPICS 10
 #define OER_SERVER_IS_STONED_FOR 300
-#define OER_LINENOISE_INTERVAL_MIN 1
+#define OER_LINENOISE_INTERVAL_MIN 0
 #define OER_MASSMODE_LIMIT 3
 #define OER_LAST 3
 #define OER_LAST_MAX 10
@@ -353,7 +403,7 @@ enum OER_FLAGS_TYPE {
 #define USERLEN 16
 #define NICKLEN 20
 #define USERHOSTLEN HOSTLEN + USERLEN + NICKLEN + 2
-#define TOPICLEN 160
+#define TOPICLEN 250
 #define TOPIC_SEPARATOR " | "
 #define CONNECTION_STATE_PREFIXES "^~+=-"
 #define OER_MAX_LIST_LINES 5
@@ -364,7 +414,7 @@ enum OER_FLAGS_TYPE {
 #define OER_SERVER_IS_STONED "stoned server"
 #define OER_INTERNAL_DYNAMIC_ADMIN "*INTDYN*"
 #define OER_REALNAME "http://oer.equnet.org"
-#define OER_VERSION "oer version 1.0-59"
+#define OER_VERSION "oer version 1.0-62"
 #define OER_COPYRIGHT1 "Copyright (C) 2000-2002 EQU <equ@equnet.org>"
 #define OER_COPYRIGHT2 "oer comes with ABSOLUTELY NO WARRANTY; for details see the\n\
 GNU General Public License (COPYING) provided with this distribution.\n\
@@ -403,6 +453,8 @@ struct locked {
 
 struct qauth {
 	int hasauth;
+	int isonline;
+	time_t lastquery;
 	int authed;
 	char q[USERHOSTLEN + 1];
 	char name[NICKLEN + 1];
@@ -446,6 +498,7 @@ struct authed {
 struct topic {
 	time_t at;
 	int list;
+	int deleted;
 	char *setby;
 	char *topic;
 	struct topic *prev;
@@ -550,6 +603,7 @@ struct channelban {
 
 struct server {
 	char serverhost[HOSTLEN + 1];
+	char serverhost_r[HOSTLEN + 1];
 	int serverport;
 	int servermodes;
 	int pingfrequency;
@@ -593,6 +647,7 @@ struct channel {
 	time_t last_quote;
 	time_t join_ts;
 	time_t requestop;
+	time_t last_advert;
 	FILE *seen;
 	FILE *last;
 	struct join *joins;
@@ -617,7 +672,9 @@ struct channel {
 };
 
 struct state {
-	char progname[STRINGLEN + 1];
+	char basedir[STRINGLEN + 1];
+	char progname[TINYSTRINGLEN + 1];
+	char altloggingdir[STRINGLEN + 1];
 	/* this is our current nick, might be temporarily set
 	   to getnick when attempting to change nick */
 	char nick[NICKLEN + 1];
